@@ -30,6 +30,7 @@
 
 #include "file-data.h"
 #include "file-utils.h"
+#include "glib-utils.h"
 #include "fr-command.h"
 #include "fr-command-lha.h"
 
@@ -311,6 +312,8 @@ fr_command_lha_class_init (FRCommandLhaClass *class)
 static void 
 fr_command_lha_init (FRCommand *comm)
 {
+	comm->file_type = FR_FILE_TYPE_LHA;
+
 	comm->propAddCanUpdate             = TRUE; 
 	comm->propAddCanReplace            = TRUE; 
 	comm->propExtractCanAvoidOverwrite = FALSE;
