@@ -32,6 +32,7 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glade/glade.h>
 #include "file-utils.h"
+#include "glib-utils.h"
 #include "fr-process.h"
 #include "fr-stock.h"
 #include "gconf-utils.h"
@@ -48,7 +49,6 @@ static void     init_session        (char **argv);
 static gboolean session_is_restored (void);
 static gboolean load_session        (void);
 
-
 GList        *window_list = NULL;
 GList        *viewer_list = NULL;
 GList        *command_list = NULL;
@@ -62,7 +62,73 @@ static gint   extract;
 static gint   extract_here;
 static gchar *default_url = NULL;
 
-extern void get_supported_archive_types (void);
+FRFileTypeDescription file_type_desc[] = {
+	{ FR_FILE_TYPE_AR,           ".ar",      "application/x-ar", N_("Ar (.ar)") },
+	{ FR_FILE_TYPE_DEB,          ".deb",     "application/x-deb", NULL },
+	{ FR_FILE_TYPE_ARJ,          ".arj",     "application/x-arj", N_("Arj (.arj)") },
+	{ FR_FILE_TYPE_BZIP,         ".bz",      "application/x-bzip", NULL },
+	{ FR_FILE_TYPE_BZIP2,        ".bz2",     "application/x-bzip", NULL },
+	{ FR_FILE_TYPE_COMPRESS,     ".Z",       "application/x-compress", NULL },
+	{ FR_FILE_TYPE_ISO,          ".iso",     "application/x-cd-image", NULL },
+	{ FR_FILE_TYPE_EAR,          ".ear",     "application/x-ear", N_("Ear (.ear)") },
+	{ FR_FILE_TYPE_GZIP,         ".gz",      "application/x-gzip", NULL},
+	{ FR_FILE_TYPE_JAR,          ".jar",     "application/x-jar", N_("Jar (.jar)")},
+	{ FR_FILE_TYPE_LHA,          ".lzh",     "application/x-lha", N_("Lha (.lzh)") },
+	{ FR_FILE_TYPE_LZOP,         ".lzo",     "application/x-lzop", NULL },
+	{ FR_FILE_TYPE_RAR,          ".rar",     "application/x-rar", N_("Rar (.rar)") },
+	{ FR_FILE_TYPE_RPM,          ".rpm",     "application/x-rpm", NULL },
+	{ FR_FILE_TYPE_TAR,          ".tar",     "application/x-tar", N_("Tar uncompressed (.tar)") },
+	{ FR_FILE_TYPE_TAR_BZ,       ".tar.bz",  "application/x-bzip-compressed-tar", N_("Tar compressed with bzip (.tar.bz)") },
+	{ FR_FILE_TYPE_TAR_BZ2,      ".tar.bz2", "application/x-bzip-compressed-tar", N_("Tar compressed with bzip2 (.tar.bz2)") },
+	{ FR_FILE_TYPE_TAR_GZ,       ".tar.gz",  "application/x-compressed-tar", N_("Tar compressed with gzip (.tar.gz)") },
+	{ FR_FILE_TYPE_TAR_LZOP,     ".tar.lzo", "application/x-lzop-compressed-tar", N_("Tar compressed with lzop (.tar.lzo)") },
+	{ FR_FILE_TYPE_TAR_COMPRESS, ".tar.Z",   "application/x-compressed-tar", N_("Tar compressed with compress (.tar.Z)") },
+	{ FR_FILE_TYPE_STUFFIT,      ".sit",     "application/x-stuffit", NULL },
+	{ FR_FILE_TYPE_WAR,          ".war",     "application/zip", N_("War (.war)") },
+	{ FR_FILE_TYPE_ZIP,          ".zip",     "application/zip", N_("Zip (.zip)") },
+	{ FR_FILE_TYPE_ZOO,          ".zoo",     "application/x-zoo", N_("Zoo (.zoo)") },
+	{ FR_FILE_TYPE_7ZIP,         ".7z",      "application/x-7z-compressed", N_("7-Zip (.7z)") }
+};
+
+
+FRFileType single_file_save_type[32];
+FRFileType save_type[32];
+FRFileType open_type[32];
+
+
+FRCommandDescription command_desc[] = {
+	{ "tar",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_TAR },
+	{ "zip",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_ZIP },
+	{ "unzip",      TRUE,  FALSE, TRUE,  FR_FILE_TYPE_ZIP },
+	{ "rar",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_RAR },
+	{ "gzip",       TRUE,  TRUE,  FALSE, FR_FILE_TYPE_GZIP },
+	{ "bzip2",      TRUE,  TRUE,  FALSE, FR_FILE_TYPE_BZIP2 },
+	{ "ar",         TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_AR },
+	{ "ar",         TRUE,  FALSE, TRUE,  FR_FILE_TYPE_DEB },
+	{ "arj",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_ARJ },
+	{ "bzip2",      TRUE,  FALSE, FALSE, FR_FILE_TYPE_BZIP },
+	{ "compress",   TRUE,  TRUE,  FALSE, FR_FILE_TYPE_COMPRESS },
+	{ "isoinfo",    TRUE,  FALSE, TRUE,  FR_FILE_TYPE_ISO },
+	{ "zip",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_EAR },
+	{ "zip",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_JAR },
+	{ "lha",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_LHA },
+	{ "lzop",       TRUE,  TRUE,  FALSE, FR_FILE_TYPE_LZOP },
+	{ "rpm2cpio",   TRUE,  FALSE, TRUE,  FR_FILE_TYPE_RPM },
+	{ "uncompress", TRUE,  FALSE, FALSE, FR_FILE_TYPE_COMPRESS },
+	{ "unstuff",    TRUE,  FALSE, FALSE, FR_FILE_TYPE_STUFFIT },
+	{ "zip",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_WAR },
+	{ "zoo",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_ZOO },
+	{ "7za",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_7ZIP }
+};
+
+FRCommandDescription tar_command_desc[] = {
+	{ "gzip",      TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_TAR_GZ },
+	{ "bzip2",     TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_TAR_BZ2 },
+	{ "bzip",      FALSE, TRUE,  TRUE,  FR_FILE_TYPE_TAR_BZ },
+	{ "lzop",      TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_TAR_LZOP },
+	{ "compress",  TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_TAR_COMPRESS }
+};
+
 
 struct poptOption options[] = {
 	{ "add-to", 'a', POPT_ARG_STRING, &add_to, 0,
@@ -119,7 +185,8 @@ startup_cb (gpointer data)
 }
 
 
-int main (int argc, char **argv)
+int 
+main (int argc, char **argv)
 {
 	GnomeProgram *program;
 	GValue value = { 0 };
@@ -345,6 +412,43 @@ migrate_to_new_directories (void)
 }
 
 
+static void 
+compute_supported_archive_types (void)
+{
+	int i, j;
+	int sf_i = 0, s_i = 0, o_i = 0;
+
+	for (i = 0; i < G_N_ELEMENTS (command_desc); i++) {
+		FRCommandDescription com = command_desc[i];
+
+		if (!is_program_in_path (com.command)) 
+			continue;
+
+		if (strcmp (com.command, "tar") == 0) 
+			for (j = 0; j < G_N_ELEMENTS (tar_command_desc); j++) {
+				FRCommandDescription com2 = tar_command_desc[j];
+				
+				if (!is_program_in_path (com2.command)) 
+					continue;
+				open_type[o_i++] = com2.file_type;
+				save_type[s_i++] = com2.file_type;
+				single_file_save_type[sf_i++] = com2.file_type;
+			}
+
+		if (com.can_open)
+			open_type[o_i++] = com.file_type;
+		if (com.can_save && com.support_many_files)
+			save_type[s_i++] = com.file_type;
+		if (com.can_save)
+			single_file_save_type[sf_i++] = com.file_type;
+	}
+
+	open_type[o_i++] = FR_FILE_TYPE_NULL;
+	save_type[s_i++] = FR_FILE_TYPE_NULL;
+	single_file_save_type[sf_i++] = FR_FILE_TYPE_NULL;
+}
+
+
 static void 
 prepare_app (poptContext pctx)
 {
@@ -367,7 +471,7 @@ prepare_app (poptContext pctx)
 	if (eel_gconf_get_boolean (PREF_MIGRATE_DIRECTORIES, TRUE))
                 migrate_to_new_directories ();
 
-	get_supported_archive_types();
+	compute_supported_archive_types();
 
 	if (session_is_restored ()) {
 		load_session ();
